@@ -1,4 +1,4 @@
-;;; vm.el --- Entry points for VM  -*- lexical-binding: t; -*-
+;;; vm.el --- VM mail reader -*- lexical-binding: t; -*-
 ;;
 ;; This file is part of VM
 ;;
@@ -6,10 +6,11 @@
 ;; Copyright (C) 2003-2006 Robert Widhopf-Fenk
 ;; Copyright (C) 2024-2025 The VM Developers
 ;;
-;; Version: 8.3.0snapshot
+;; Version: 8.3.1snapshot
 ;; Maintainer: viewmail-info@nongnu.org
 ;; URL: https://gitlab.com/emacs-vm/vm
-;; Package-Requires: ((emacs "28.0") (vcard "0.2.2"))
+;; Package-Requires: ((emacs "28.1") (vcard "0.2.2"))
+;; Keywords: mail
 ;;
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -25,10 +26,13 @@
 ;; with this program; if not, write to the Free Software Foundation, Inc.,
 ;; 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-
-;;; History:
-;;
-;; This file was vm-startup.el!
+;;; Commentary:
+;; VM mail reader for Emacs
+;; It is designed ot be highly configurable and easy to use. It supports POP
+;; and IMAP mail servers, understands MIME, and handles mail folders in the
+;; standard UNIX mailbox format and the BABYL format used by the RMAIL
+;; mailer. It has a powerful virtual folder facility to facilitate searching
+;; as well as more advanced handling of multiple mail folders.
 
 ;;; Code:
 
@@ -58,7 +62,8 @@
 (eval-when-compile (require 'cl-lib))
 (require 'package)
 
-(defconst vm-min-emacs-version "28.0"
+;; keep vm-min-emacs-version in sync with above Package-Requires
+(defconst vm-min-emacs-version "28.1"
   "Minimum Emacs version supported by VM.")
 
 (defvar enable-multibyte-characters)
@@ -78,7 +83,7 @@
 
 ;; vm-xemacs.el is a non-existent file to fool the Emacs 23 compiler
 (declare-function get-coding-system "vm-xemacs.el" (name))
-(declare-function find-face "vm-xemacs.el" (face-or-name))
+(declare-function facep "vm-xemacs.el" (face-or-name))
 
 (declare-function vm-rfaddons-infect-vm "vm-rfaddons.el" 
 		  (&optional sit-for option-list exclude-option-list))
@@ -90,11 +95,14 @@
   (error "VM requires Emacs %s or later" vm-min-emacs-version))
 
 
-;; Ensure that vm-autoloads is loaded in case the user is using VM
-;; autoloads 
-
-(if (not (featurep 'xemacs))
-    (require 'vm-autoloads))
+;; emacs 28 doesn't generate a provide in when generating autoloads
+;; yet does bbdb-vm.el  (require 'vm-autoloads). This workds around
+;; this issue, yet allows vm.el to work if evaluated without going through
+;; vm-autoloads.
+(if (<= emacs-major-version 28)
+    (progn
+      (load-library "vm-autoloads")
+      (provide 'vm-autoloads)))
 
 ;;;###autoload
 (cl-defun vm (&optional folder &key read-only interactive
@@ -1544,30 +1552,6 @@ summary buffer to select a folder."
   (interactive)
   (find-file-other-frame vm-init-file))
 
-(defun vm-check-emacs-version ()
-  "Checks the version of Emacs and gives an error if it is unsupported."
-  (cond ((and (featurep 'xemacs) (< emacs-major-version 21))
-	 (error "VM %s must be run on XEmacs 21 or a later version."
-		(vm-version)))
-	((and (not (featurep 'xemacs)) (< emacs-major-version 21))
-	 (error "VM %s must be run on GNU Emacs 21 or a later version."
-		(vm-version)))))
-
-;; This function is now defunct.  USR, 2011-11-12
-
-;; (defun vm-set-debug-flags ()
-;;   (or stack-trace-on-error
-;;       debug-on-error
-;;       (setq stack-trace-on-error
-;; 	    '(
-;; 	      wrong-type-argument
-;; 	      wrong-number-of-arguments
-;; 	      args-out-of-range
-;; 	      void-function
-;; 	      void-variable
-;; 	      invalid-function
-;; 	     ))))
-
 (defun vm-toggle-thread-operations ()
   "Toggle the variable `vm-enable-thread-operations'.
 
@@ -1609,11 +1593,9 @@ attributes, adding/deleting labels etc."
   "If this is the first time VM has been run in this Emacs session,
 do some necessary preparations.  Otherwise, update the count of
 draft messages."
-  ;;  (vm-set-debug-flags)
   (if (or (not (boundp 'vm-session-beginning))
 	  vm-session-beginning)
       (progn
-        (vm-check-emacs-version)
         (require 'vm-macro)
         (require 'vm-vars)
         (require 'vm-misc)
@@ -1716,9 +1698,8 @@ draft messages."
 (defun vm--commit-from-package (pkg)
   "Get commit hash from PKG, whether VC-installed or archive-installed."
   (let ((desc (package-get-descriptor pkg)))
-    (or (when (package-vc-p desc)
-          (package-vc-commit desc))
-        (alist-get :commit (package-desc-extras desc)))))
+    (or (alist-get :commit (package-desc-extras desc))
+        "unknown-commit")))
 
 (defun vm--version-info-from-package ()
   "Return version and commit if VM is loaded from a package."
